# orx

A modern, async, lightweight Discord API wrapper.

## Key Features

- Efficient and robust ratelimit handling
- Consistently and accurately typed
- Provides low-level access for customisability

### What Orx is **not**

- A high level wrapper for people who just want a simple API wrapper, for that use discord.py or a similar fork of it.

## Installing

**Orx requires Python 3.10 or higher.**

To install Orx you can use:

```sh
# Linux/MacOS
python3 -m pip install orx

# Windows
py -3 -m pip install Orx
```

## Versioning

Orx is versioned according to semantic versioning with minor modifications.

The version format is `major.minor.patch`, i.e. `1.0.0`.

- Major version changes may have large breaking changes to how the library works.
- Minor version changes may have small breaking changes, for example a single method's signature changing.
- Patch version changes should not include breaking changes.

Some versions released on pypi may use the a format similar to `1.0.0a0` or `1.0.0rc0`. These are alpha and release candidate versions. It is not recommended that you use these versions in production instances of your bots.

## Contributing

See [Contributing to Orx](./CONTRIBUTING.md).
